#!/usr/bin/perl
# Do not normalise this test file. It has deliberately unnormalised characters in it.
use v5.10;
use strict;
use warnings;
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Test::More tests => 25;
use Test::Exception;

use ok 'Locale::CLDR';

my $locale = Locale::CLDR->new('br_FR');
my $other_locale = Locale::CLDR->new('en_US');

is($locale->locale_name(), 'brezhoneg (Frañs)', 'Locale name from current locale');
is($locale->locale_name('fr_CA'), 'galleg Kanada', 'Locale name from string');
is($locale->locale_name($other_locale), 'saozneg Amerika', 'Locale name from other locale object');

is($locale->language_name(), 'brezhoneg', 'Language name from current locale');
is($locale->language_name('fr'), 'galleg', 'Language name from string');
is($locale->language_name($other_locale), 'saozneg', 'Language name from other locale object');

my $all_languages = {
    'aa' => 'afar',
    'ab' => 'abkhazeg',
    'ace' => 'achineg',
    'ach' => 'acoli',
    'ada' => 'adangme',
    'ady' => 'adygeieg',
    'ae' => 'avesteg',
    'aeb' => 'arabeg Tunizia',
    'af' => 'afrikaans',
    'afh' => 'afrihili',
    'agq' => 'aghem',
    'ain' => 'ainoueg',
    'ak' => 'akan',
    'akk' => 'akadeg',
    'akz' => 'alabamaeg',
    'ale' => 'aleouteg',
    'aln' => 'gegeg',
    'alt' => 'altaieg ar Su',
    'am' => 'amhareg',
    'an' => 'aragoneg',
    'ang' => 'hensaozneg',
    'ar' => 'arabeg',
    'ar_001' => 'arabeg modern',
    'arc' => 'arameeg',
    'arn' => 'araoukaneg',
    'arp' => 'arapaho',
    'arq' => 'arabeg Aljeria',
    'arw' => 'arawakeg',
    'ary' => 'arabeg Maroko',
    'arz' => 'arabeg Egipt',
    'as' => 'asameg',
    'asa' => 'asu',
    'av' => 'avar',
    'awa' => 'awadhi',
    'ay' => 'aymara',
    'az' => 'azeri',
    'azb' => 'azeri ar Su',
    'ba' => 'bachkir',
    'bal' => 'baloutchi',
    'ban' => 'balineg',
    'bar' => 'bavarieg',
    'bas' => 'basaa',
    'be' => 'belaruseg',
    'bej' => 'bedawieg',
    'bem' => 'bemba',
    'bez' => 'bena',
    'bg' => 'bulgareg',
    'bho' => 'bhojpuri',
    'bi' => 'bislama',
    'bik' => 'bikol',
    'bin' => 'bini',
    'bm' => 'bambara',
    'bn' => 'bengali',
    'bo' => 'tibetaneg',
    'br' => 'brezhoneg',
    'bra' => 'braj',
    'brh' => 'brahweg',
    'brx' => 'bodo',
    'bs' => 'bosneg',
    'bua' => 'bouriat',
    'bug' => 'bugi',
    'byn' => 'blin',
    'ca' => 'katalaneg',
    'cad' => 'caddo',
    'car' => 'karibeg',
    'ce' => 'tchetcheneg',
    'ceb' => 'cebuano',
    'ch' => 'chamorru',
    'chb' => 'chibcha',
    'chm' => 'marieg',
    'cho' => 'choktaw',
    'chp' => 'chipewyan',
    'chr' => 'cherokee',
    'chy' => 'cheyenne',
    'ckb' => 'kurdeg sorani',
    'co' => 'korseg',
    'cop' => 'kopteg',
    'cr' => 'kri',
    'crh' => 'turkeg Krimea',
    'cs' => 'tchekeg',
    'csb' => 'kachoubeg',
    'cu' => 'slavoneg iliz',
    'cv' => 'tchouvatch',
    'cy' => 'kembraeg',
    'da' => 'daneg',
    'dak' => 'dakota',
    'dar' => 'dargwa',
    'de' => 'alamaneg',
    'de_AT' => 'alamaneg Aostria',
    'de_CH' => 'alamaneg uhel Suis',
    'del' => 'delaware',
    'dgr' => 'dogrib',
    'din' => 'dinka',
    'doi' => 'dogri',
    'dsb' => 'izelsorabeg',
    'dum' => 'nederlandeg krenn',
    'dv' => 'divehi',
    'dyu' => 'dyula',
    'dz' => 'dzongkha',
    'ebu' => 'embu',
    'ee' => 'ewe',
    'efi' => 'efik',
    'egy' => 'henegipteg',
    'eka' => 'ekajuk',
    'el' => 'gresianeg',
    'elx' => 'elameg',
    'en' => 'saozneg',
    'en_AU' => 'saozneg Aostralia',
    'en_CA' => 'saozneg Kanada',
    'en_GB' => 'saozneg Breizh-Veur',
    'en_GB@alt=short' => 'saozneg R.U.',
    'en_US' => 'saozneg Amerika',
    'en_US@alt=short' => 'saozneg S.U.',
    'enm' => 'krennsaozneg',
    'eo' => 'esperanteg',
    'es' => 'spagnoleg',
    'es_419' => 'spagnoleg Amerika latin',
    'es_ES' => 'spagnoleg Europa',
    'es_MX' => 'spagnoleg Mecʼhiko',
    'et' => 'estoneg',
    'eu' => 'euskareg',
    'ewo' => 'ewondo',
    'fa' => 'perseg',
    'fan' => 'fang',
    'fat' => 'fanti',
    'fi' => 'finneg',
    'fil' => 'filipineg',
    'fj' => 'fidjieg',
    'fo' => 'faeroeg',
    'fon' => 'fon',
    'fr' => 'galleg',
    'fr_CA' => 'galleg Kanada',
    'fr_CH' => 'galleg Suis',
    'frm' => 'krenncʼhalleg',
    'fro' => 'hencʼhalleg',
    'frp' => 'arpitaneg',
    'frr' => 'frizeg an Norzh',
    'frs' => 'frizeg ar Reter',
    'fur' => 'frioulaneg',
    'fy' => 'frizeg ar Cʼhornôg',
    'ga' => 'iwerzhoneg',
    'gaa' => 'ga',
    'gag' => 'gagaouzeg',
    'gan' => 'sinaeg Gan',
    'gay' => 'gayo',
    'gba' => 'gbaya',
    'gd' => 'skoseg',
    'gez' => 'gezeg',
    'gil' => 'gilberteg',
    'gl' => 'galizeg',
    'gmh' => 'krennalamaneg uhel',
    'gn' => 'guarani',
    'goh' => 'henalamaneg uhel',
    'gor' => 'gorontalo',
    'got' => 'goteg',
    'grb' => 'grebo',
    'grc' => 'hencʼhresianeg',
    'gsw' => 'alamaneg Suis',
    'gu' => 'gujarati',
    'gv' => 'manaveg',
    'ha' => 'haousa',
    'hai' => 'haida',
    'hak' => 'sinaeg Hakka',
    'haw' => 'hawaieg',
    'he' => 'hebraeg',
    'hi' => 'hindi',
    'hil' => 'hiligaynon',
    'hmn' => 'hmong',
    'ho' => 'hiri motu',
    'hr' => 'kroateg',
    'hsb' => 'uhelsorabeg',
    'hsn' => 'sinaeg Xian',
    'ht' => 'haitieg',
    'hu' => 'hungareg',
    'hup' => 'hupa',
    'hy' => 'armenianeg',
    'hz' => 'herero',
    'ia' => 'interlingua',
    'iba' => 'iban',
    'ibb' => 'ibibio',
    'id' => 'indonezeg',
    'ie' => 'interlingue',
    'ig' => 'igbo',
    'ii' => 'yieg Sichuan',
    'ik' => 'inupiaq',
    'inh' => 'ingoucheg',
    'io' => 'ido',
    'is' => 'islandeg',
    'it' => 'italianeg',
    'iu' => 'inuktitut',
    'ja' => 'japaneg',
    'jpr' => 'yuzev-perseg',
    'jrb' => 'yuzev-arabeg',
    'jv' => 'javaneg',
    'ka' => 'jorjianeg',
    'kaa' => 'karakalpak',
    'kab' => 'kabileg',
    'kac' => 'kachin',
    'kam' => 'kamba',
    'kbd' => 'kabardeg',
    'kea' => 'kabuverdianu',
    'kg' => 'kongo',
    'kha' => 'khasi',
    'kho' => 'khotaneg',
    'ki' => 'kikuyu',
    'kj' => 'kwanyama',
    'kk' => 'kazak',
    'km' => 'khmer',
    'kmb' => 'kimbundu',
    'kn' => 'kanareg',
    'ko' => 'koreaneg',
    'kok' => 'konkani',
    'kos' => 'kosrae',
    'kpe' => 'kpelle',
    'kr' => 'kanouri',
    'krc' => 'karatchay-balkar',
    'kri' => 'krio',
    'krl' => 'karelieg',
    'kru' => 'kurukh',
    'ks' => 'kashmiri',
    'ku' => 'kurdeg',
    'kut' => 'kutenai',
    'kw' => 'kerneveureg',
    'ky' => 'kirgiz',
    'la' => 'latin',
    'lad' => 'ladino',
    'lah' => 'lahnda',
    'lam' => 'lamba',
    'lb' => 'luksembourgeg',
    'lez' => 'lezgi',
    'lfn' => 'lingua franca nova',
    'lg' => 'ganda',
    'li' => 'limbourgeg',
    'lij' => 'ligurieg',
    'ln' => 'lingala',
    'lo' => 'laoseg',
    'lol' => 'mongo',
    'loz' => 'lozi',
    'lt' => 'lituaneg',
    'lu' => 'luba-katanga',
    'lua' => 'luba-lulua',
    'lui' => 'luiseno',
    'lun' => 'lunda',
    'luo' => 'luo',
    'lus' => 'lushai',
    'luy' => 'luyia',
    'lv' => 'latvieg',
    'lzh' => 'sinaeg lennegel',
    'mag' => 'magahi',
    'mai' => 'maithili',
    'mas' => 'masai',
    'mdf' => 'moksha',
    'mdr' => 'mandar',
    'men' => 'mende',
    'mfe' => 'moriseg',
    'mg' => 'malgacheg',
    'mga' => 'krenniwerzhoneg',
    'mh' => 'marshall',
    'mi' => 'maori',
    'mk' => 'makedoneg',
    'ml' => 'malayalam',
    'mn' => 'mongoleg',
    'mnc' => 'manchou',
    'mni' => 'manipuri',
    'moh' => 'mohawk',
    'mr' => 'marathi',
    'mrj' => 'marieg ar Cʼhornôg',
    'ms' => 'malayseg',
    'mt' => 'malteg',
    'mul' => 'yezhoù lies',
    'mus' => 'muskogi',
    'my' => 'birmaneg',
    'myv' => 'erza',
    'na' => 'naurueg',
    'nan' => 'sinaeg Min Nan',
    'nap' => 'napolitaneg',
    'nb' => 'norvegeg bokmål',
    'nd' => 'ndebele an Norzh',
    'nds' => 'alamaneg izel',
    'ne' => 'nepaleg',
    'new' => 'newari',
    'ng' => 'ndonga',
    'nia' => 'nias',
    'niu' => 'niue',
    'nl' => 'nederlandeg',
    'nl_BE' => 'flandrezeg',
    'nn' => 'norvegeg nynorsk',
    'no' => 'norvegeg',
    'nog' => 'nogay',
    'non' => 'hennorseg',
    'nov' => 'novial',
    'nr' => 'ndebele ar Su',
    'nso' => 'sotho an Norzh',
    'nv' => 'navacʼho',
    'nwc' => 'newari klasel',
    'ny' => 'nyanja',
    'nym' => 'nyamwezi',
    'nyn' => 'nyankole',
    'nyo' => 'nyoro',
    'oc' => 'okitaneg',
    'oj' => 'ojibwa',
    'or' => 'oriya',
    'os' => 'oseteg',
    'osa' => 'osage',
    'ota' => 'turkeg otoman',
    'pa' => 'punjabi',
    'pag' => 'pangasinan',
    'pal' => 'pahlavi',
    'pam' => 'pampanga',
    'pap' => 'papiamento',
    'pau' => 'palau',
    'pcd' => 'pikardeg',
    'pdc' => 'alamaneg Pennsylvania',
    'peo' => 'henberseg',
    'phn' => 'fenikianeg',
    'pi' => 'pali',
    'pl' => 'poloneg',
    'pms' => 'piemonteg',
    'pnt' => 'ponteg',
    'pon' => 'pohnpei',
    'prg' => 'henbruseg',
    'pro' => 'henbrovañseg',
    'ps' => 'pachto',
    'pt' => 'portugaleg',
    'pt_BR' => 'portugaleg Brazil',
    'pt_PT' => 'portugaleg Europa',
    'qu' => 'kechuaeg',
    'raj' => 'rajasthani',
    'rap' => 'rapanui',
    'rar' => 'rarotonga',
    'rgn' => 'romagnoleg',
    'rm' => 'romañcheg',
    'rn' => 'rundi',
    'ro' => 'roumaneg',
    'ro_MD' => 'moldoveg',
    'rof' => 'rombo',
    'rom' => 'romanieg',
    'ru' => 'rusianeg',
    'rup' => 'aroumaneg',
    'rw' => 'kinyarwanda',
    'rwk' => 'rwa',
    'sa' => 'sanskriteg',
    'sad' => 'sandawe',
    'sah' => 'yakouteg',
    'sam' => 'arameeg ar Samaritaned',
    'sas' => 'sasak',
    'sat' => 'santali',
    'sc' => 'sardeg',
    'scn' => 'sikilieg',
    'sco' => 'skoteg',
    'sd' => 'sindhi',
    'sdc' => 'sasareseg',
    'se' => 'sámi an Norzh',
    'sg' => 'sango',
    'sga' => 'heniwerzhoneg',
    'sh' => 'serb-kroateg',
    'shn' => 'shan',
    'shu' => 'arabeg Tchad',
    'si' => 'singhaleg',
    'sid' => 'sidamo',
    'sk' => 'slovakeg',
    'sl' => 'sloveneg',
    'sm' => 'samoan',
    'sma' => 'sámi ar Su',
    'smj' => 'sámi Luleå',
    'smn' => 'sámi Inari',
    'sms' => 'sámi Skolt',
    'sn' => 'shona',
    'snk' => 'soninke',
    'so' => 'somali',
    'sog' => 'sogdieg',
    'sq' => 'albaneg',
    'sr' => 'serbeg',
    'srr' => 'serer',
    'ss' => 'swati',
    'st' => 'sotho ar Su',
    'su' => 'sundaneg',
    'sux' => 'sumereg',
    'sv' => 'svedeg',
    'sw' => 'swahili',
    'swb' => 'komoreg',
    'syc' => 'sirieg klasel',
    'syr' => 'sirieg',
    'ta' => 'tamileg',
    'tcy' => 'touloueg',
    'te' => 'telougou',
    'ter' => 'tereno',
    'tet' => 'tetum',
    'tg' => 'tadjik',
    'th' => 'thai',
    'ti' => 'tigrigna',
    'tig' => 'tigreaneg',
    'tiv' => 'tiv',
    'tk' => 'turkmeneg',
    'tkl' => 'tokelau',
    'tl' => 'tagalog',
    'tlh' => 'klingon',
    'tli' => 'tinglit',
    'tmh' => 'tamacheg',
    'tn' => 'tswana',
    'to' => 'tonga',
    'tog' => 'nyasa tonga',
    'tpi' => 'tok pisin',
    'tr' => 'turkeg',
    'ts' => 'tsonga',
    'tsi' => 'tsimshian',
    'tt' => 'tatar',
    'tum' => 'tumbuka',
    'tvl' => 'tuvalu',
    'tw' => 'twi',
    'ty' => 'tahitianeg',
    'tyv' => 'touva',
    'udm' => 'oudmourteg',
    'ug' => 'ouigoureg',
    'uga' => 'ougariteg',
    'uk' => 'ukraineg',
    'umb' => 'umbundu',
    'und' => 'yezh dianav',
    'ur' => 'ourdou',
    'uz' => 'ouzbekeg',
    'vai' => 'vai',
    've' => 'venda',
    'vi' => 'vietnameg',
    'vls' => 'flandrezeg ar c’hornôg',
    'vo' => 'volapük',
    'vot' => 'votyakeg',
    'wa' => 'walloneg',
    'wae' => 'walser',
    'wal' => 'walamo',
    'war' => 'waray',
    'was' => 'washo',
    'wo' => 'wolof',
    'wuu' => 'sinaeg Wu',
    'xal' => 'kalmouk',
    'xh' => 'xhosa',
    'yao' => 'yao',
    'yap' => 'yapeg',
    'yi' => 'yiddish',
    'yo' => 'yorouba',
    'yue' => 'kantoneg',
    'za' => 'zhuang',
    'zap' => 'zapoteg',
    'zbl' => 'Bliss',
    'zea' => 'zelandeg',
    'zen' => 'zenaga',
    'zgh' => 'tamacheg Maroko standart',
    'zh' => 'sinaeg',
    'zh_Hans' => 'sinaeg eeunaet',
    'zh_Hant' => 'sinaeg hengounel',
    'zu' => 'zouloueg',
    'zun' => 'zuni',
    'zxx' => 'diyezh',
};

is_deeply($locale->all_languages, $all_languages, 'All languages');

is($locale->script_name(), '', 'Script name from current locale');
is($locale->script_name('latn'), 'latin', 'Script name from string');
is($locale->script_name($other_locale), '', 'Script name from other locale object');

my $all_scripts = {
    'Arab' => 'arabek',
    'Armi' => 'arameek impalaerel',
    'Armn' => 'armenianek',
    'Avst' => 'avestek',
    'Bali' => 'balinek',
    'Beng' => 'bengali',
    'Bopo' => 'bopomofo',
    'Brai' => 'Braille',
    'Bugi' => 'bougiek',
    'Copt' => 'koptek',
    'Cyrl' => 'kirillek',
    'Cyrs' => 'kirillek henslavonek',
    'Deva' => 'devanagari',
    'Egyp' => 'hieroglifoù egiptek',
    'Ethi' => 'etiopek',
    'Geor' => 'jorjianek',
    'Glag' => 'glagolitek',
    'Goth' => 'gotek',
    'Grek' => 'gresianek',
    'Gujr' => 'gujarati',
    'Guru' => 'gurmukhi',
    'Hang' => 'hangeul',
    'Hani' => 'han',
    'Hans' => 'eeunaet',
    'Hans@alt=stand-alone' => 'han eeunaet',
    'Hant' => 'hengounel',
    'Hant@alt=stand-alone' => 'han hengounel',
    'Hebr' => 'hebraek',
    'Hira' => 'hiragana',
    'Hluw' => 'hieroglifoù Anatolia',
    'Ital' => 'henitalek',
    'Java' => 'javanek',
    'Jpan' => 'japanek',
    'Kana' => 'katakana',
    'Khmr' => 'khmer',
    'Knda' => 'kannada',
    'Kore' => 'koreanek',
    'Laoo' => 'laosek',
    'Latg' => 'latin gouezelek',
    'Latn' => 'latin',
    'Maya' => 'hieroglifoù mayaek',
    'Mlym' => 'malayalam',
    'Mong' => 'mongolek',
    'Mymr' => 'myanmar',
    'Ogam' => 'ogam',
    'Orya' => 'oriya',
    'Runr' => 'runek',
    'Sinh' => 'singhalek',
    'Sund' => 'sundanek',
    'Syrc' => 'siriek',
    'Syre' => 'siriek Estrangelā',
    'Syrj' => 'siriek ar C’hornôg',
    'Syrn' => 'siriek ar Reter',
    'Taml' => 'tamilek',
    'Telu' => 'telougou',
    'Tglg' => 'tagalog',
    'Thaa' => 'thaana',
    'Thai' => 'thai',
    'Tibt' => 'tibetanek',
    'Ugar' => 'ougaritek',
    'Vaii' => 'vai',
    'Xpeo' => 'persek kozh',
    'Zmth' => 'notadur jedoniel',
    'Zsym' => 'arouezioù',
    'Zxxx' => 'anskrivet',
    'Zyyy' => 'boutin',
    'Zzzz' => 'skritur dianav',
};

is_deeply($locale->all_scripts, $all_scripts, 'All scripts');

is($locale->territory_name(), 'Frañs', 'Territory name from current locale');
is($locale->territory_name('en_US'), 'Rannved dianav', 'Territory name from string');
is($locale->territory_name($other_locale), 'Stadoù-Unanet', 'Territory name from other locale object');

my $all_territories = {
    '001' => 'Bed',
    '002' => 'Afrika',
    '003' => 'Norzhamerika',
    '005' => 'Suamerika',
    '009' => 'Oseania',
    '011' => 'Afrika ar Cʼhornôg',
    '013' => 'Kreizamerika',
    '014' => 'Afrika ar Reter',
    '015' => 'Afrika an Norzh',
    '017' => 'Afrika ar Cʼhreiz',
    '018' => 'Afrika ar Su',
    '019' => 'Amerikaoù',
    '021' => 'Amerika an Norzh',
    '029' => 'Karib',
    '030' => 'Azia ar Reter',
    '034' => 'Azia ar Su',
    '035' => 'Azia ar Gevred',
    '039' => 'Europa ar Su',
    '053' => 'Aostralazia',
    '054' => 'Melanezia',
    '057' => 'Rannved Mikronezia',
    '061' => 'Polinezia',
    '142' => 'Azia',
    '143' => 'Azia ar Cʼhreiz',
    '145' => 'Azia ar Cʼhornôg',
    '150' => 'Europa',
    '151' => 'Europa ar Reter',
    '154' => 'Europa an Norzh',
    '155' => 'Europa ar Cʼhornôg',
    '419' => 'Amerika Latin',
    'AC' => 'Enez Ascension',
    'AD' => 'Andorra',
    'AE' => 'Emirelezhioù Arab Unanet',
    'AF' => 'Afghanistan',
    'AG' => 'Antigua ha Barbuda',
    'AI' => 'Anguilla',
    'AL' => 'Albania',
    'AM' => 'Armenia',
    'AN' => 'Antilhez Nederlandat',
    'AO' => 'Angola',
    'AQ' => 'Antarktika',
    'AR' => 'Arcʼhantina',
    'AS' => 'Samoa Amerikan',
    'AT' => 'Aostria',
    'AU' => 'Aostralia',
    'AW' => 'Aruba',
    'AX' => 'Inizi Åland',
    'AZ' => 'Azerbaidjan',
    'BA' => 'Bosnia ha Herzegovina',
    'BB' => 'Barbados',
    'BD' => 'Bangladesh',
    'BE' => 'Belgia',
    'BF' => 'Burkina Faso',
    'BG' => 'Bulgaria',
    'BH' => 'Bahrein',
    'BI' => 'Burundi',
    'BJ' => 'Benin',
    'BL' => 'Saint Barthélemy',
    'BM' => 'Bermuda',
    'BN' => 'Brunei',
    'BO' => 'Bolivia',
    'BQ' => 'Nederlandat Karib',
    'BR' => 'Brazil',
    'BS' => 'Bahamas',
    'BT' => 'Bhoutan',
    'BV' => 'Enez Bouvet',
    'BW' => 'Botswana',
    'BY' => 'Belarus',
    'BZ' => 'Belize',
    'CA' => 'Kanada',
    'CC' => 'Inizi Kokoz',
    'CD' => 'Kongo - Kinshasa',
    'CD@alt=variant' => 'Kongo (RDK)',
    'CF' => 'Republik Kreizafrikan',
    'CG' => 'Kongo - Brazzaville',
    'CG@alt=variant' => 'Kongo (Republik)',
    'CH' => 'Suis',
    'CI' => 'Aod an Olifant',
    'CI@alt=variant' => 'Aod Olifant',
    'CK' => 'Inizi Cook',
    'CL' => 'Chile',
    'CM' => 'Kameroun',
    'CN' => 'Sina',
    'CO' => 'Kolombia',
    'CP' => 'Enez Clipperton',
    'CR' => 'Costa Rica',
    'CU' => 'Kuba',
    'CV' => 'Kab Glas',
    'CW' => 'Curaçao',
    'CX' => 'Enez Christmas',
    'CY' => 'Kiprenez',
    'CZ' => 'Republik Tchek',
    'DE' => 'Alamagn',
    'DG' => 'Diego Garcia',
    'DJ' => 'Djibouti',
    'DK' => 'Danmark',
    'DM' => 'Dominica',
    'DO' => 'Republik Dominikan',
    'DZ' => 'Aljeria',
    'EA' => 'Ceuta ha Melilla',
    'EC' => 'Ecuador',
    'EE' => 'Estonia',
    'EG' => 'Egipt',
    'EH' => 'Sahara ar Cʼhornôg',
    'ER' => 'Eritrea',
    'ES' => 'Spagn',
    'ET' => 'Etiopia',
    'EU' => 'Unaniezh Europa',
    'FI' => 'Finland',
    'FJ' => 'Fidji',
    'FK' => 'Inizi Falkland',
    'FK@alt=variant' => 'Inizi Falkland (Inizi Maloù)',
    'FM' => 'Mikronezia',
    'FO' => 'Inizi Faero',
    'FR' => 'Frañs',
    'GA' => 'Gabon',
    'GB' => 'Rouantelezh-Unanet',
    'GB@alt=short' => 'R.U.',
    'GD' => 'Grenada',
    'GE' => 'Jorjia',
    'GF' => 'Gwiana cʼhall',
    'GG' => 'Gwernenez',
    'GH' => 'Ghana',
    'GI' => 'Jibraltar',
    'GL' => 'Greunland',
    'GM' => 'Gambia',
    'GN' => 'Ginea',
    'GP' => 'Gwadeloup',
    'GQ' => 'Ginea ar Cʼheheder',
    'GR' => 'Gres',
    'GS' => 'Inizi Georgia ar Su hag Inizi Sandwich ar Su',
    'GT' => 'Guatemala',
    'GU' => 'Guam',
    'GW' => 'Ginea-Bissau',
    'GY' => 'Guyana',
    'HK' => 'Hong Kong RMD Sina',
    'HK@alt=short' => 'Hong Kong',
    'HM' => 'Inizi Heard ha McDonald',
    'HN' => 'Honduras',
    'HR' => 'Kroatia',
    'HT' => 'Haiti',
    'HU' => 'Hungaria',
    'IC' => 'Inizi Kanariez',
    'ID' => 'Indonezia',
    'IE' => 'Iwerzhon',
    'IL' => 'Israel',
    'IM' => 'Enez Vanav',
    'IN' => 'India',
    'IO' => 'Tiriad breizhveurat Meurvor Indez',
    'IQ' => 'Iraq',
    'IR' => 'Iran',
    'IS' => 'Island',
    'IT' => 'Italia',
    'JE' => 'Jerzenez',
    'JM' => 'Jamaika',
    'JO' => 'Jordania',
    'JP' => 'Japan',
    'KE' => 'Kenya',
    'KG' => 'Kyrgyzstan',
    'KH' => 'Kambodja',
    'KI' => 'Kiribati',
    'KM' => 'Komorez',
    'KN' => 'Saint Kitts ha Nevis',
    'KP' => 'Korea an Norzh',
    'KR' => 'Korea ar Su',
    'KW' => 'Koweit',
    'KY' => 'Inizi Cayman',
    'KZ' => 'Kazakstan',
    'LA' => 'Laos',
    'LB' => 'Liban',
    'LC' => 'Saint Lucia',
    'LI' => 'Liechtenstein',
    'LK' => 'Sri Lanka',
    'LR' => 'Liberia',
    'LS' => 'Lesotho',
    'LT' => 'Lituania',
    'LU' => 'Luksembourg',
    'LV' => 'Latvia',
    'LY' => 'Libia',
    'MA' => 'Maroko',
    'MC' => 'Monaco',
    'MD' => 'Moldova',
    'ME' => 'Montenegro',
    'MF' => 'Saint Martin',
    'MG' => 'Madagaskar',
    'MH' => 'Inizi Marshall',
    'MK' => 'Makedonia',
    'MK@alt=variant' => 'Makedonia (RYKM)',
    'ML' => 'Mali',
    'MM' => 'Myanmar (Birmania)',
    'MN' => 'Mongolia',
    'MO' => 'Macau RMD Sina',
    'MO@alt=short' => 'Macau',
    'MP' => 'Inizi Mariana an Norzh',
    'MQ' => 'Martinik',
    'MR' => 'Maouritania',
    'MS' => 'Montserrat',
    'MT' => 'Malta',
    'MU' => 'Moris',
    'MV' => 'Maldivez',
    'MW' => 'Malawi',
    'MX' => 'Mecʼhiko',
    'MY' => 'Malaysia',
    'MZ' => 'Mozambik',
    'NA' => 'Namibia',
    'NC' => 'Kaledonia Nevez',
    'NE' => 'Niger',
    'NF' => 'Enez Norfolk',
    'NG' => 'Nigeria',
    'NI' => 'Nicaragua',
    'NL' => 'Izelvroioù',
    'NO' => 'Norvegia',
    'NP' => 'Nepal',
    'NR' => 'Nauru',
    'NU' => 'Niue',
    'NZ' => 'Zeland-Nevez',
    'OM' => 'Oman',
    'PA' => 'Panamá',
    'PE' => 'Perou',
    'PF' => 'Polinezia Cʼhall',
    'PG' => 'Papoua Ginea-Nevez',
    'PH' => 'Filipinez',
    'PK' => 'Pakistan',
    'PL' => 'Polonia',
    'PM' => 'Sant-Pêr-ha-Mikelon',
    'PN' => 'Enez Pitcairn',
    'PR' => 'Puerto Rico',
    'PS' => 'Tiriadoù Palestina',
    'PS@alt=short' => 'Palestina',
    'PT' => 'Portugal',
    'PW' => 'Palau',
    'PY' => 'Paraguay',
    'QA' => 'Qatar',
    'QO' => 'Oseania diabell',
    'RE' => 'Reünion',
    'RO' => 'Roumania',
    'RS' => 'Serbia',
    'RU' => 'Rusia',
    'RW' => 'Rwanda',
    'SA' => 'Arabia Saoudat',
    'SB' => 'Salomon',
    'SC' => 'Sechelez',
    'SD' => 'Soudan',
    'SE' => 'Sveden',
    'SG' => 'Singapour',
    'SH' => 'Saint-Helena',
    'SI' => 'Slovenia',
    'SJ' => 'Svalbard',
    'SK' => 'Slovakia',
    'SL' => 'Sierra Leone',
    'SM' => 'San Marino',
    'SN' => 'Senegal',
    'SO' => 'Somalia',
    'SR' => 'Surinam',
    'SS' => 'Susoudan',
    'ST' => 'São Tomé ha Príncipe',
    'SV' => 'Salvador',
    'SX' => 'Sint Maarten',
    'SY' => 'Siria',
    'SZ' => 'Swaziland',
    'TA' => 'Tristan da Cunha',
    'TC' => 'Inizi Turks ha Caicos',
    'TD' => 'Tchad',
    'TF' => 'Douaroù aostral Frañs',
    'TG' => 'Togo',
    'TH' => 'Thailand',
    'TJ' => 'Tadjikistan',
    'TK' => 'Tokelau',
    'TL' => 'Timor-Leste',
    'TL@alt=variant' => 'Timor ar Reter',
    'TM' => 'Turkmenistan',
    'TN' => 'Tunizia',
    'TO' => 'Tonga',
    'TR' => 'Turkia',
    'TT' => 'Trinidad ha Tobago',
    'TV' => 'Tuvalu',
    'TW' => 'Taiwan',
    'TZ' => 'Tanzania',
    'UA' => 'Ukraina',
    'UG' => 'Ouganda',
    'UM' => 'Inizi diabell ar Stadoù-Unanet',
    'US' => 'Stadoù-Unanet',
    'US@alt=short' => 'S.U.',
    'UY' => 'Uruguay',
    'UZ' => 'Ouzbekistan',
    'VA' => 'Vatikan',
    'VC' => 'Sant Visant hag ar Grenadinez',
    'VE' => 'Venezuela',
    'VG' => 'Inizi Gwercʼh Breizh-Veur',
    'VI' => 'Inizi Gwercʼh ar Stadoù-Unanet',
    'VN' => 'Viêt Nam',
    'VU' => 'Vanuatu',
    'WF' => 'Wallis ha Futuna',
    'WS' => 'Samoa',
    'XK' => 'Kosovo',
    'YE' => 'Yemen',
    'YT' => 'Mayotte',
    'ZA' => 'Suafrika',
    'ZM' => 'Zambia',
    'ZW' => 'Zimbabwe',
    'ZZ' => 'Rannved dianav',
};

is_deeply($locale->all_territories(), $all_territories, 'All Territories');

is($locale->variant_name(), '', 'Variant name from current locale');
is($locale->variant_name('JYUTPING'), 'romanekadur kantonek Jyutping', 'Variant name from string');
is($locale->variant_name($other_locale), '', 'Variant name from other locale object');

is($locale->key_name('collation'), 'doare rummañ', 'Key name from string');

is($locale->type_name(collation => 'standard'), 'urzh rummañ standart', 'Type name from string');

is($locale->measurement_system_name('metric'), 'metrek', 'Measurement system name English Metric');
is($locale->measurement_system_name('us'), 'SU', 'Measurement system name English US');
is($locale->measurement_system_name('uk'), 'RU', 'Measurement system name English UK');

is($locale->transform_name('Numeric'), '', 'Transform name from string');